@@ -46,9 +46,7 @@ class VersionInfo(object):
         associated with the package."""
         try:
             requirement = pkg_resources.Requirement.parse(self.package)
-            print "requirement %s" % requirement.__class__.__name__
             provider = pkg_resources.get_provider(requirement)
-            print "provider %s" % provider.__class__.__name__
             return provider.version
         except pkg_resources.DistributionNotFound:
             # The most likely cause for this is running tests in a tree
